/* 
   This file is part of KDE project.
   Copyright (C) 2004 Dawit Alemayehu <adawit@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation, version 2.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <qmap.h>
#include <qstring.h>
#include <qvaluelist.h>

#include <kuniqueapplication.h>

class KBrokenLibDetectorUI;

class KBrokenLibDetector : public KUniqueApplication
{
  Q_OBJECT;
  
  struct LibInfo
  {
    QString baseName;
    QString fullPath;
  };
  
  typedef QValueList<LibInfo> InfoList;
  
public:
  KBrokenLibDetector();
  virtual ~KBrokenLibDetector();
  virtual int newInstance();
  
protected slots:
  void slotStart();
  void slotStop();
  void slotQuit();
  void slotDetails();
  void slotHighlighted(int);
  
  void startChecking();

private:
  void reset();
  void updateButtons();
  void addBrokenLib(const QString&);
  void findLibs( const QString&, InfoList*, bool recurse = false );
 
private:
  bool _run;
  QString _libPath;
  QMap<QString,QString> _errorMap;
  
  KBrokenLibDetectorUI* _widget;
};
